@@ -63,6 +63,7 @@ MedalPreset = Literal["ccpc", "icpc"]
 BannerMode = Literal["ONLY_BANNER", "ALL"]
 Lang = Literal["en", "zh-CN"]
 DateTimeISO8601String = str
+UrlString = str
 
 
 class I18NStringSet(BaseModel):
@@ -81,11 +82,26 @@ class Image(BaseModel):
     base64: Optional[str] = None
     type: Optional[Literal["png", "svg", "jpg", "jpeg"]] = None
 
-    preset: Optional[ImagePreset] = None
-
     width: Optional[int] = None
     height: Optional[int] = None
 
+    preset: Optional[ImagePreset] = None
+
+
+class DataItem(BaseModel):
+    url: UrlString
+    version: Optional[str] = None
+
+
+class Organization(BaseModel):
+    id: str
+    name: Text
+
+    logo: Optional[Image] = None
+
+
+Organizations = List[Organization]
+
 
 class BalloonColor(BaseModel):
     color: str
@@ -146,6 +162,8 @@ class Team(BaseModel):
     name: Text = ""
 
     organization: str = ""
+    organization_id: Optional[str] = None
+
     group: List[str] = Field(default_factory=list)
     tag: Optional[List[str]] = None
 
@@ -187,6 +205,8 @@ class ContestOptions(BaseModel):
 
 class Contest(BaseModel):
     contest_name: Text = ""
+    description: Optional[Text] = None
+    og_image: Optional[Image] = None
 
     start_time: Union[int, DateTimeISO8601String] = 0
     end_time: Union[int, DateTimeISO8601String] = 0
@@ -213,13 +233,15 @@ class Contest(BaseModel):
     logo: Optional[Image] = None
     banner: Optional[Image] = None
     banner_mode: Optional[BannerMode] = None
-    board_link: Optional[str] = None
-
-    version: Optional[str] = None
 
     options: Optional[ContestOptions] = None
 
-    unfrozen_time: int = Field(default=0x3F3F3F3F3F3F3F3F, exclude=True)
+    organizations: Optional[Union[DataItem, Organizations]] = None
+
+    board_link: Optional[str] = None
+    version: Optional[str] = None
+
+    thaw_time: int = Field(default=0x3F3F3F3F3F3F3F3F, exclude=True)
 
     def append_balloon_color(self, color: BalloonColor):
         if self.balloon_color is None:
